@@ -14,6 +14,7 @@ class Local(object):
         self.last_install = 0
         self.install_locked = False
         self.roles = []
+        self._install_roles = None
         self._roles = {}
         self._owned = {}
         self._locked = False
@@ -135,7 +136,7 @@ class Local(object):
 
         return self._roles[name]
     
-    def mark_role_order(self):
+    def mark_role_order(self, mark_roles=None):
         '''Go through all roles and mark the order field based on the role's installation depth'''
         def recurse_order(roles, order=1):
             if len(roles) == 0:
@@ -146,7 +147,9 @@ class Local(object):
                 order += 1
             recurse_order(list(itertools.chain(*[self.role(name).mixins for name in roles])), order)
 
-        recurse_order(self.roles)
+        if mark_roles is None:
+            mark_roles = self.roles
+        recurse_order(mark_roles)
 
     def sync_down(self):
         '''Copy from the repository to the current working directory'''
@@ -313,8 +316,10 @@ class Local(object):
             roles = self.roles
         elif save:
             self.roles = list(set(self.roles).union(set(roles)))
+        
+        self._install_roles = roles
         # Roles should be added general-to-specific, but installed specific-to-general
-        roles = roles.reverse()
+        roles.reverse()
 
         if self.repo is not None:
             self.mirror()
@@ -330,6 +335,7 @@ class Local(object):
         self.run_postinstalls(change_files)
         
         self.last_install = time.time()
+        self._install_roles = None
         self.save()
         if unlock: self.unlock()
 
@@ -456,7 +462,7 @@ class Local(object):
             ordered.append((script, args))
 
         if len(ordered) > 0:
-            self.mark_role_order()
+            self.mark_role_order(self._install_roles)
             ordered.sort(key=lambda x: -self.role(os.path.basename(os.path.dirname(x[0])))._order)
 
         return ordered
